@@ -17,7 +17,7 @@
 #include "webserver.h"
 #include "WebPages.h"
 
-#define VERSION 2.5
+#define VERSION "2.5.3"
 
 extern char *getfqdn(char *);
 extern void trim(char *);
@@ -143,7 +143,7 @@ int Status_Page(char *source, char *dest, int size)
 {
 	if(source && dest && size) {
 		snprintf(dest,size,
-			"<HTML><BODY><H1><CENTER>Welcome to SNARE for Solaris version 2.5.2</H1><P>Please select from the menu on the left.</CENTER><p>\nStatus: <font color=green>Snare for Solaris currently running.</font>\n</BODY></HTML>");
+			"<HTML><BODY><H1><CENTER>Welcome to SNARE for Solaris version %s</H1><P>Please select from the menu on the left.</CENTER><p>\nStatus: <font color=green>Snare for Solaris currently running.</font>\n</BODY></HTML>",VERSION);
 	}
 	return (0);
 }
@@ -366,7 +366,7 @@ int RunJass(int http_socket, char *source, char *dest, int size)
 	FILE *jass_pipe;
 
 	if(!file_exists("/opt/SUNWjass/bin/jass-execute")) {
-		strncpy(dest,"<b>The <a href=\"http://www.google.com/search?q=jass+solaris\">Solaris JASS</a> application does not seem to be installed in the /opt/SUNWjass directory. Cannot continue.<br><br>Please see the Sun Web Site for download details.</b><br>",size);
+		strncpy(dest,"<b>The <a href=\"http://www.google.com/search?q=jass+solaris\">Solaris JASS</a> application does not seem to be installed in the /opt/SUNWjass directory. In particular, I cannot find the /opt/SUNWjass/bin/jass-execute binary. Cannot continue.<br><br>Please see the Sun Web Site for download details.</b><br>",size);
 		return(-1);
 	}
 		
@@ -1457,7 +1457,7 @@ int Objective_Display(char *source, char *dest, int size)
 			i_set = 1;
 		}
 		strncat(dest,
-			">Read, write or create a file or directory  </td></tr><tr><td><input type=radio name=str_eventid_match value=",
+			">Write or create a file or directory  </td></tr><tr><td><input type=radio name=str_eventid_match value=",
 			size - strlen(dest));
 		strncat(dest, FILE_ATTRIB_TOKEN, size - strlen(dest));
 		if (strcmp
