@@ -1,6 +1,6 @@
 /**********************************************************
  *
- * Snare for Solaris version 2.5.1
+ * Snare for Solaris version 2.5.3
  *
  * Author: InterSect Alliance Pty Ltd
  *
@@ -256,7 +256,7 @@ int main(int argc, char *argv[])
 				exit(1);
 			} else {
 				/* Turn on some specific audit conditions. */
-				auditpolicy = auditpolicy | AUDIT_ARGV | AUDIT_SEQ | AUDIT_CNT;
+				auditpolicy = auditpolicy | AUDIT_ARGV | AUDIT_SEQ | AUDIT_CNT | AUDIT_PUBLIC | AUDIT_PASSWD;
 				if(auditon(A_SETPOLICY,(caddr_t)&auditpolicy,sizeof(auditpolicy)) == -1)
 				{
 					fprintf(stderr,"Could not set the audit policy to include exec, execv and sequence data in audit information.\n");
@@ -486,8 +486,16 @@ int main(int argc, char *argv[])
 					   better be installed before we make this
 					   system call, or the machine will halt! */
 
-					auditsvc(daemon2praudit[1],0);
-					error=errno;
+					// auditsvc(daemon2praudit[1],0);
+					if(daemon2praudit[1]) {
+						auditsvc(daemon2praudit[1],1);
+						error=errno;
+					} else {
+						// Something very strange has
+						// occurred. Terminate and try
+						// again.
+						error=EINTR;
+					}
 
 					/* ignore non fatal errors at this time. */
 					if(error==EINVAL)
@@ -501,7 +509,7 @@ int main(int argc, char *argv[])
 						exit(1);
 					} else if(error == EBUSY) {
 						/* Auditing is already being performed by another process */
-						fprintf(stderr,"Another process has control of audit.\n");
+						fprintf(stderr,"Another process has control of audit.\n  Please check that there is not another Snare process already running, and verify that the standard Solaris audit daemon is not still active.");
 						if(argc == 1) { audit_off(); }
 						if(webpid) {
 							kill(webpid,SIGTERM);
@@ -587,7 +595,6 @@ int main(int argc, char *argv[])
 						continue;
 					}
 				}
-
 				bytesread=read(praudit2daemon[0],bufferptr,spaceavail);
 				if(!bytesread) {
 					break;
