@@ -12,7 +12,8 @@
         #define SALT "$1$Snare$"
 #else
         // Solaris
-        #define SALT "$md5"
+        // #define SALT "$md5"
+        #define SALT "$1"
 #endif
 
 void	decodeurl(char *pEncoded);
